@@ -4,15 +4,15 @@ from django.contrib.auth.tests import urls
 
 from allauth.socialaccount.providers.facebook.views import FacebookOAuth2Adapter
 
-from .urls import urlpatterns
-from .registration.views import SocialLogin
+from rest_auth.urls import urlpatterns
+from rest_auth.registration.views import SocialLogin
 
 
 class FacebookLogin(SocialLogin):
     adapter_class = FacebookOAuth2Adapter
 
 urlpatterns += patterns('',
-    url(r'^rest-registration/', include('registration.urls')),
+    url(r'^rest-registration/', include('rest_auth.registration.urls')),
     url(r'^test-admin/', include(urls)),
     url(r'^account-email-verification-sent/$', TemplateView.as_view(),
         name='account_email_verification_sent'),
